@@ -20,10 +20,6 @@ type Cache interface {
 	Delete(key string)
 }
 
-type Context interface {
-	CacheKey() (string, bool)
-}
-
 const (
 	FileName = "omp.cache"
 )
