@@ -10,7 +10,7 @@ import (
 	"github.com/spf13/cobra"
 )
 
-// migrateCmd represents the migrate command
+// migrateGlyphsCmd represents the glyphs command
 var migrateGlyphsCmd = &cobra.Command{
 	Use:   "glyphs",
 	Short: "Migrate the nerd font glyphs in your config",
@@ -35,11 +35,10 @@ Migrates the ~/myconfig.omp.json config file's glyphs and writes the result to y
 A backup of the current config can be found at ~/myconfig.omp.json.bak.`,
 	Args: cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
-		configFile := config.Path(configFlag)
-		cfg, _ := config.Load(configFile, shell.GENERIC, false)
+		cfg, _ := config.Load(configFlag, shell.GENERIC, false)
 
 		flags := &runtime.Flags{
-			Config: configFile,
+			Config: cfg.Source,
 		}
 
 		env := &runtime.Terminal{}
