@@ -75,6 +75,7 @@ type Segment struct {
 	InvertPowerline        bool           `json:"invert_powerline,omitempty" toml:"invert_powerline,omitempty" yaml:"invert_powerline,omitempty"`
 	Force                  bool           `json:"force,omitempty" toml:"force,omitempty" yaml:"force,omitempty"`
 	restored               bool           `json:"-" toml:"-" yaml:"-"`
+	Index                  int            `json:"index,omitempty" toml:"index,omitempty" yaml:"index,omitempty"`
 }
 
 func (segment *Segment) Name() string {
@@ -299,16 +300,12 @@ func (segment *Segment) cacheKey() string {
 }
 
 func (segment *Segment) folderKey() string {
-	ctx, ok := segment.writer.(cache.Context)
+	key, ok := segment.writer.CacheKey()
 	if !ok {
 		return segment.env.Pwd()
 	}
 
-	if key, OK := ctx.CacheKey(); OK {
-		return key
-	}
-
-	return segment.env.Pwd()
+	return key
 }
 
 func (segment *Segment) string() string {
@@ -387,3 +384,11 @@ func (segment *Segment) evaluateNeeds() {
 		segment.Needs = append(segment.Needs, segmentName)
 	}
 }
+
+func (segment *Segment) key() any {
+	if segment.Index > 0 {
+		return segment.Index - 1
+	}
+
+	return segment.Name()
+}
