@@ -17,42 +17,49 @@ const (
 type Text string
 
 func (t Text) Green() Text {
-	if plain {
+	if raw {
 		return t
 	}
 	return "\x1b[38;2;191;207;240m" + t
 }
 
 func (t Text) Red() Text {
-	if plain {
+	if raw {
 		return t
 	}
 	return "\x1b[38;2;253;122;140m" + t
 }
 
 func (t Text) Purple() Text {
-	if plain {
+	if raw {
 		return t
 	}
 	return "\x1b[38;2;204;137;214m" + t
 }
 
 func (t Text) Yellow() Text {
-	if plain {
+	if raw {
 		return t
 	}
 	return "\x1b[38;2;156;231;201m" + t
 }
 
+func (t Text) Orange() Text {
+	if raw {
+		return t
+	}
+	return "\x1b[38;2;253;184;109m" + t
+}
+
 func (t Text) Bold() Text {
-	if plain {
+	if raw {
 		return t
 	}
 	return "\x1b[1m" + t
 }
 
 func (t Text) Plain() Text {
-	if plain {
+	if raw {
 		return t
 	}
 	return t + "\033[0m"
