@@ -4,31 +4,25 @@ import (
 	"encoding/json"
 	"errors"
 	"path/filepath"
+	"slices"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 
 	"github.com/hashicorp/hcl/v2/gohcl"
 	"github.com/hashicorp/hcl/v2/hclparse"
 )
 
 type Terraform struct {
-	props properties.Properties
-	env   runtime.Environment
+	base
 
-	WorkspaceName string
 	TerraformBlock
+	WorkspaceName string
 }
 
 func (tf *Terraform) Template() string {
 	return " {{ .WorkspaceName }}{{ if .Version }} {{ .Version }}{{ end }} "
 }
 
-func (tf *Terraform) Init(props properties.Properties, env runtime.Environment) {
-	tf.props = props
-	tf.env = env
-}
-
 type TerraFormConfig struct {
 	Terraform *TerraformBlock `hcl:"terraform,block"`
 }
@@ -66,10 +60,8 @@ func (tf *Terraform) inContext(fetchVersion bool) bool {
 	}
 
 	files := []string{".tf", ".tfplan", ".tfstate"}
-	for _, file := range files {
-		if tf.env.HasFiles(file) {
-			return true
-		}
+	if slices.ContainsFunc(files, tf.env.HasFiles) {
+		return true
 	}
 
 	if !fetchVersion {
@@ -77,13 +69,7 @@ func (tf *Terraform) inContext(fetchVersion bool) bool {
 	}
 
 	versionFiles := []string{"versions.tf", "main.tf", "terraform.tfstate"}
-	for _, file := range versionFiles {
-		if tf.env.HasFiles(file) {
-			return true
-		}
-	}
-
-	return false
+	return slices.ContainsFunc(versionFiles, tf.env.HasFiles)
 }
 
 func (tf *Terraform) setVersionFromTfFiles() error {
